@@ -16,7 +16,12 @@ def read_schema(fname):
 
 def save_json(data: dict, fname):
     with open(fname, "w") as fout:
-        json.dump(data, fout, indent=2, ensure_ascii=False)
+        json.dump(
+            data,
+            fout,
+            indent=2,
+            ensure_ascii=False
+        )
 
 
 class Log(IntEnum):
